@@ -43,7 +43,8 @@ from .datamodels import (ZoneEnergyLabelingData,
                          SecurityHubFindingsResourcesData,
                          SecurityHubFindingsTypesData,
                          LabeledAccountsData,
-                         LabeledAccountData)
+                         LabeledAccountData,
+                         Metadata)
 
 __author__ = 'Costas Tyfoxylos <ctyfoxylos@schubergphilis.com>'
 __docformat__ = '''google'''
@@ -119,7 +120,7 @@ def get_available_security_hub_regions():
         with urllib.request.urlopen(url) as response:
             response_json = json.loads(response.read())
     except (urllib.error.URLError, ValueError):
-        raise UnableToRetrieveSecurityHubRegions('Failed to retrieve applicable AWS regions')
+        raise UnableToRetrieveSecurityHubRegions('Failed to retrieve applicable AWS regions') from None
     return [entry.get('id', '').split(':')[1]
             for entry in response_json.get('prices')
             if entry.get('id').startswith('securityhub')]
@@ -156,11 +157,15 @@ FILE_EXPORT_TYPES = [
      'filename': 'account-energy-label.json',
      'object_type': LabeledAccountData,
      'required_arguments': ['labeled_accounts']},
+    {'type': 'metadata',
+     'filename': 'metadata.json',
+     'object_type': Metadata,
+     'required_arguments': ['metadata']},
 ]
 
-ZONE_METRIC_EXPORT_TYPES = ['zone_energy_label', 'labeled_accounts']
+ZONE_METRIC_EXPORT_TYPES = ['zone_energy_label', 'labeled_accounts', 'metadata']
 
-ACCOUNT_METRIC_EXPORT_TYPES = ['account_energy_label']
+ACCOUNT_METRIC_EXPORT_TYPES = ['account_energy_label', 'metadata']
 
 DATA_EXPORT_TYPES = ['findings', 'findings_resources', 'findings_types']
 
